.. _support:

support and contact channels
=====================================

Getting in contact:

* join the `tox-dev mailing list`_ for tox related questions and development discussions.
* file a `report on the issue tracker`_
* hang out on the irc.freenode.net #pylib channel
* `fork the github repository`_ and submit merge/pull requests (see the developers help page -- :ref:`developers`)

paid professional support
----------------------------

contact holger at `merlinux.eu`_, an association of
experienced well-known Python developers.

.. _`Testing In Python (TIP) mailing list`: http://lists.idyll.org/listinfo/testing-in-python
.. _`holger's twitter presence`: http://twitter.com/hpk42
.. _`merlinux.eu`: http://merlinux.eu
.. _`report on the issue tracker`: https://github.com/tox-dev/tox/issues
.. _`tetamap blog`: http://holgerkrekel.net
.. _`tox-dev mailing list`: https://mail.python.org/mm3/mailman3/lists/tox-dev.python.org/
.. _`fork the github repository`: https://github.com/tox-dev/tox
